monthseditor — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »
- editors »

# monthseditor

class `camelot.view.controls.editors.monthseditor.` `MonthsEditor`(parent=None, editable=True, field_name='months', **kw)

  MonthsEditor

  composite months and years editor

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »
- editors »

Comments
blog comments powered by Disqus